Script 'mail_helper' called by obssrc
Hello community,
here is the log from the commit of package gmmlib for openSUSE:Factory checked in at 2025-01-05 15:31:46
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/gmmlib (Old)
and /work/SRC/openSUSE:Factory/.gmmlib.new.1881 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Package is "gmmlib"
Sun Jan 5 15:31:46 2025 rev:36 rq:1234910 version:22.5.5
Changes:
--------
--- /work/SRC/openSUSE:Factory/gmmlib/gmmlib.changes 2024-09-12 17:00:19.238748525 +0200
+++ /work/SRC/openSUSE:Factory/.gmmlib.new.1881/gmmlib.changes 2025-01-05 15:32:05.043804928 +0100
@@ -1,0 +2,12 @@
+Wed Dec 18 12:27:01 UTC 2024 - Bjørn Lie <bjorn.lie(a)gmail.com>
+
+- Update to version 22.5.5:
+ * Add new media compression mode to fix assertion (#224)
+ * Adjust BaseWidth for RGB24 format (#64)
+ * Enable IsCpuCacheable in Linux (#214)
+ * PAT MOCS Programming for test (#223)
+ * Make R10G10B10_XR_BIAS_A2_UNORM as presentable (#222)
+ * Add new DG2 Device ID (#221)
+ * Update reserved PATIndex (#220)
+
+-------------------------------------------------------------------
Old:
----
intel-gmmlib-22.5.2.tar.gz
New:
----
intel-gmmlib-22.5.5.tar.gz
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Other differences:
------------------
++++++ gmmlib.spec ++++++
--- /var/tmp/diff_new_pack.nzKFQ5/_old 2025-01-05 15:32:05.995844084 +0100
+++ /var/tmp/diff_new_pack.nzKFQ5/_new 2025-01-05 15:32:05.999844248 +0100
@@ -19,7 +19,7 @@
%global somajor 12
%global libname libigdgmm%{somajor}
Name: gmmlib
-Version: 22.5.2
+Version: 22.5.5
Release: 0
Summary: Intel Graphics Memory Management Library Package
License: MIT
++++++ intel-gmmlib-22.5.2.tar.gz -> intel-gmmlib-22.5.5.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Android.bp new/gmmlib-intel-gmmlib-22.5.5/Android.bp
--- old/gmmlib-intel-gmmlib-22.5.2/Android.bp 1970-01-01 01:00:00.000000000 +0100
+++ new/gmmlib-intel-gmmlib-22.5.5/Android.bp 2024-11-29 11:17:25.000000000 +0100
@@ -0,0 +1,160 @@
+// Copyright (c) 2024, Intel Corporation
+
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
+
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+// OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+// OTHER DEALINGS IN THE SOFTWARE.
+
+package {
+ default_applicable_licenses: ["external_gmmlib_license"],
+}
+
+license {
+ name: "external_gmmlib_license",
+ visibility: [":__subpackages__"],
+ license_text: [
+ "LICENSE.md",
+ ],
+}
+
+cc_library_shared {
+ name: "libigdgmm_android",
+ vendor: true,
+ srcs: [
+ "Source/GmmLib/CachePolicy/GmmCachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmCachePolicyCommon.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen10CachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen11CachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen12CachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen12dGPUCachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen8CachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmGen9CachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmXe2_LPGCachePolicy.cpp",
+ "Source/GmmLib/CachePolicy/GmmXe_LPGCachePolicy.cpp",
+ "Source/GmmLib/GlobalInfo/GmmClientContext.cpp",
+ "Source/GmmLib/GlobalInfo/GmmInfo.cpp",
+ "Source/GmmLib/GlobalInfo/GmmLibDllMain.cpp",
+ "Source/GmmLib/Platform/GmmGen10Platform.cpp",
+ "Source/GmmLib/Platform/GmmGen11Platform.cpp",
+ "Source/GmmLib/Platform/GmmGen12Platform.cpp",
+ "Source/GmmLib/Platform/GmmGen8Platform.cpp",
+ "Source/GmmLib/Platform/GmmGen9Platform.cpp",
+ "Source/GmmLib/Platform/GmmPlatform.cpp",
+ "Source/GmmLib/Resource/GmmResourceInfo.cpp",
+ "Source/GmmLib/Resource/GmmResourceInfoCommon.cpp",
+ "Source/GmmLib/Resource/GmmResourceInfoCommonEx.cpp",
+ "Source/GmmLib/Resource/GmmRestrictions.cpp",
+ "Source/GmmLib/Resource/Linux/GmmResourceInfoLinCWrapper.cpp",
+ "Source/GmmLib/Texture/GmmGen10Texture.cpp",
+ "Source/GmmLib/Texture/GmmGen11Texture.cpp",
+ "Source/GmmLib/Texture/GmmGen12Texture.cpp",
+ "Source/GmmLib/Texture/GmmGen7Texture.cpp",
+ "Source/GmmLib/Texture/GmmGen8Texture.cpp",
+ "Source/GmmLib/Texture/GmmGen9Texture.cpp",
+ "Source/GmmLib/Texture/GmmTexture.cpp",
+ "Source/GmmLib/Texture/GmmTextureAlloc.cpp",
+ "Source/GmmLib/Texture/GmmTextureOffset.cpp",
+ "Source/GmmLib/Texture/GmmTextureSpecialCases.cpp",
+ "Source/GmmLib/Texture/GmmXe_LPGTexture.cpp",
+ "Source/GmmLib/TranslationTable/GmmAuxTable.cpp",
+ "Source/GmmLib/TranslationTable/GmmPageTableMgr.cpp",
+ "Source/GmmLib/TranslationTable/GmmUmdTranslationTable.cpp",
+ "Source/GmmLib/Utility/CpuSwizzleBlt/CpuSwizzleBlt.c",
+ "Source/GmmLib/Utility/GmmLog/GmmLog.cpp",
+ "Source/GmmLib/Utility/GmmUtility.cpp",
+ "Source/Common/AssertTracer/AssertTracer.cpp",
+ ],
+
+ cflags: [
+ "-DGMM_LIB_DLL",
+ "-DGMM_LIB_DLL_EXPORTS",
+ "-DGMM_UNIFIED_LIB",
+ "-DGMM_UNIFY_DAF_API",
+ "-DISTDLIB_UMD",
+ "-DSMALL_POOL_ALLOC",
+ "-DUNUSED_ISTDLIB_MT",
+ "-D_ATL_NO_WIN_SUPPORT",
+ "-D_RELEASE",
+ "-D_X64",
+ "-D__GFX_MACRO_C__",
+ "-D__GMM",
+ "-D__STDC_CONSTANT_MACROS",
+ "-D__STDC_LIMIT_MACROS",
+ "-D__UMD",
+ "-Digfx_gmmumd_dll_EXPORTS",
+ "-fvisibility=hidden",
+ "-fno-omit-frame-pointer",
+ "-march=corei7",
+ "-Werror",
+ "-Wno-logical-op-parentheses",
+ "-Wno-shift-negative-value",
+ "-Wno-unused-parameter",
+ ],
+
+ cppflags: [
+ "-Wno-implicit-fallthrough",
+ "-Wno-missing-braces",
+ "-Wno-unknown-pragmas",
+ "-Wno-parentheses",
+ "-Wno-pragma-pack",
+ "-fexceptions",
+ "-std=c++11",
+ "-fvisibility-inlines-hidden",
+ "-fno-use-cxa-atexit",
+ "-fno-rtti",
+ "-fcheck-new",
+ "-pthread",
+ ],
+
+ local_include_dirs: [
+ "Source/GmmLib",
+ "Source/GmmLib/Utility/GmmLog",
+ "Source/GmmLib/inc",
+ "Source/GmmLib/Utility",
+ "Source/GmmLib/GlobalInfo",
+ "Source/GmmLib/Texture",
+ "Source/GmmLib/Resource",
+ "Source/GmmLib/Platform",
+ "Source/util",
+ "Source/inc",
+ "Source/inc/common",
+ "Source/inc/umKmInc",
+ ],
+
+ enabled: false,
+ arch: {
+ x86_64: {
+ enabled: true,
+ },
+ },
+}
+
+cc_library_headers {
+ name: "libigdgmm_headers",
+ vendor: true,
+ export_include_dirs: [
+ "Source/GmmLib/inc",
+ "Source/inc",
+ "Source/inc/common",
+ ],
+
+ enabled: false,
+ arch: {
+ x86_64: {
+ enabled: true,
+ },
+ },
+}
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CMakeLists.txt new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CMakeLists.txt
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CMakeLists.txt 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CMakeLists.txt 2024-11-29 11:17:25.000000000 +0100
@@ -439,8 +439,6 @@
${BS_DIR_INC}
${BS_DIR_INC}/common
${BS_DIR_INC}/umKmInc
- ${BS_DIR_INSTALL}
- #${BS_DIR_ANDROID}/include
)
if(${CMAKE_SYSTEM_PROCESSOR} MATCHES "^aarch")
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CachePolicy/GmmXe_LPGCachePolicy.cpp new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CachePolicy/GmmXe_LPGCachePolicy.cpp
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CachePolicy/GmmXe_LPGCachePolicy.cpp 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CachePolicy/GmmXe_LPGCachePolicy.cpp 2024-11-29 11:17:25.000000000 +0100
@@ -386,7 +386,7 @@
}
// Fixed MOCS Table
// Index LookUp Go L3CC L4CC ignorePAT
- GMM_DEFINE_MOCS( 0 , 1 , 0 , L3_WB , L4_WB , 1)
+ GMM_DEFINE_MOCS( 0 , 1 , 0 , L3_WB , L4_WB , 0)
GMM_DEFINE_MOCS( 1 , 1 , 0 , L3_WB , L4_WB , 1)
GMM_DEFINE_MOCS( 2 , 1 , 0 , L3_UC , L4_WB , 1)
GMM_DEFINE_MOCS( 3 , 1 , 0 , L3_UC , L4_UC , 1)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/Texture/GmmGen12Texture.cpp new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/Texture/GmmGen12Texture.cpp
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/Texture/GmmGen12Texture.cpp 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/Texture/GmmGen12Texture.cpp 2024-11-29 11:17:25.000000000 +0100
@@ -316,6 +316,11 @@
Height = pTexInfo->BaseHeight;
Width = GFX_ULONG_CAST(pTexInfo->BaseWidth);
+ if((pTexInfo->Format == GMM_FORMAT_R8G8B8_UINT) && (pTexInfo->Flags.Info.Linear || pTexInfo->Flags.Info.TiledX))
+ {
+ Width += GFX_CEIL_DIV(Width, 63);
+ }
+
pTexInfo->MSAA.NumSamples = GFX_MAX(pTexInfo->MSAA.NumSamples, 1);
if(pTexInfo->Flags.Info.TiledYf || GMM_IS_64KB_TILE(pTexInfo->Flags))
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/Texture/GmmGen9Texture.cpp new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/Texture/GmmGen9Texture.cpp
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/Texture/GmmGen9Texture.cpp 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/Texture/GmmGen9Texture.cpp 2024-11-29 11:17:25.000000000 +0100
@@ -153,8 +153,12 @@
/////////////////////////////
// Calculate Surface QPitch
/////////////////////////////
-
- Width = __GMM_EXPAND_WIDTH(this, GFX_ULONG_CAST(pTexInfo->BaseWidth), HAlign, pTexInfo);
+ Width = GFX_ULONG_CAST(pTexInfo->BaseWidth);
+ if((pTexInfo->Format == GMM_FORMAT_R8G8B8_UINT) && (pTexInfo->Flags.Info.Linear || pTexInfo->Flags.Info.TiledX))
+ {
+ Width += GFX_CEIL_DIV(Width, 63);
+ }
+ Width = __GMM_EXPAND_WIDTH(this, Width, HAlign, pTexInfo);
MipWidth = Width;
if((pTexInfo->Flags.Info.TiledYf || GMM_IS_64KB_TILE(pTexInfo->Flags)) &&
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmFormatTable.h new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmFormatTable.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmFormatTable.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmFormatTable.h 2024-11-29 11:17:25.000000000 +0100
@@ -443,7 +443,7 @@
GMM_FORMAT( P012 , 16, 1, 1, 1, R, x, NA , NC , ALWAYS )
GMM_FORMAT( P016 , 16, 1, 1, 1, R, x, NA , FC(4, x, P016, ,_L ), ALWAYS )
GMM_FORMAT( P208 , 8, 1, 1, 1, R, x, NA , NC , ALWAYS )
-GMM_FORMAT( R10G10B10_XR_BIAS_A2_UNORM , 32, 1, 1, 1, x, x, NA , FC(4, x, RGB10A2, , ), ALWAYS ) // DXGI_FORMAT_R10G10B10_XR_BIAS_A2_UNORM
+GMM_FORMAT( R10G10B10_XR_BIAS_A2_UNORM , 32, 1, 1, 1, R, x, NA , FC(4, x, RGB10A2, , ), ALWAYS ) // DXGI_FORMAT_R10G10B10_XR_BIAS_A2_UNORM
GMM_FORMAT( R24G8_TYPELESS , 32, 1, 1, 1, x, x, NA , FC(4, 32, R, 32, U), ALWAYS ) // DXGI_FORMAT_R24G8_TYPELESS (To differentiate between GENERIC_32BIT.)
GMM_FORMAT( R32G8X24_TYPELESS , 64, 1, 1, 1, x, x, NA , FC(4, 32, R, 32, U), ALWAYS ) // DXGI_FORMAT_R32G8X24_TYPELESS (To differentiate between GENERIC_64BIT.)
GMM_FORMAT( RENDER_8BIT , 8, 1, 1, 1, R, x, NA , NC , ALWAYS )
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmResourceInfoCommon.h new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmResourceInfoCommon.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmResourceInfoCommon.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmResourceInfoCommon.h 2024-11-29 11:17:25.000000000 +0100
@@ -715,7 +715,7 @@
/////////////////////////////////////////////////////////////////////////////////////
GMM_INLINE_VIRTUAL GMM_INLINE_EXPORTED void GMM_STDCALL SetMmcMode(GMM_RESOURCE_MMC_INFO Mode, uint32_t ArrayIndex)
{
- __GMM_ASSERT((Mode == GMM_MMC_DISABLED) || (Mode == GMM_MMC_HORIZONTAL) || (Mode == GMM_MMC_VERTICAL));
+ __GMM_ASSERT((Mode == GMM_MMC_DISABLED) || (Mode == GMM_MMC_HORIZONTAL) || (Mode == GMM_MMC_VERTICAL) || (Mode == GMM_MMC_MC) || (Mode == GMM_MMC_RC));
__GMM_ASSERT(ArrayIndex < GMM_MAX_MMC_INDEX);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmResourceInfoExt.h new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmResourceInfoExt.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/inc/External/Common/GmmResourceInfoExt.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/inc/External/Common/GmmResourceInfoExt.h 2024-11-29 11:17:25.000000000 +0100
@@ -59,6 +59,8 @@
GMM_MMC_DISABLED = 0,
GMM_MMC_HORIZONTAL,
GMM_MMC_VERTICAL,
+ GMM_MMC_MC,
+ GMM_MMC_RC
}GMM_RESOURCE_MMC_INFO;
//===========================================================================
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/inc/common/igfxfmid.h new/gmmlib-intel-gmmlib-22.5.5/Source/inc/common/igfxfmid.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/inc/common/igfxfmid.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/inc/common/igfxfmid.h 2024-11-29 11:17:25.000000000 +0100
@@ -399,7 +399,7 @@
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
#define GFX_IS_GEN_8_OR_LATER(p) ( ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN8_CORE ) || \
@@ -409,7 +409,7 @@
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
#define GFX_IS_GEN_8_CHV_OR_LATER(p) ( ( GFX_GET_CURRENT_PRODUCT(p) == IGFX_CHERRYVIEW ) || \
@@ -419,7 +419,7 @@
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
#define GFX_IS_GEN_9_OR_LATER(p) ( ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN9_CORE ) || \
@@ -428,7 +428,7 @@
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
#define GFX_IS_GEN_10_OR_LATER(p) (( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN10_CORE ) || \
@@ -436,15 +436,16 @@
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
#define GFX_IS_GEN_11_OR_LATER(p) (( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN11_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GEN12_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HP_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPG_CORE ) || \
- ( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_XE_HPC_CORE ) || \
+ ( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_XE_HPC_CORE ) || \
( GFX_GET_CURRENT_RENDERCORE(p) == IGFX_GENNEXT_CORE ) )
+
#define GFX_IS_GEN_12_OR_LATER(p) (( GFX_GET_CURRENT_RENDERCORE(p) >= IGFX_GEN12_CORE ))
#define GFX_IS_ATOM_PRODUCT_FAMILY(p) ( GFX_IS_PRODUCT(p, IGFX_VALLEYVIEW) || \
GFX_IS_PRODUCT(p, IGFX_CHERRYVIEW) || \
@@ -1936,6 +1937,7 @@
#define DEV_ID_56A4 0x56A4
#define DEV_ID_56A5 0x56A5
#define DEV_ID_56A6 0x56A6
+#define DEV_ID_56AF 0x56AF
#define DEV_ID_56B0 0x56B0
#define DEV_ID_56B1 0x56B1
#define DEV_ID_56B2 0x56B2
@@ -2033,7 +2035,8 @@
( d == DEV_ID_4F81 ) || \
( d == DEV_ID_4F82 ) || \
( d == DEV_ID_4F83 ) || \
- ( d == DEV_ID_4F84 ))
+ ( d == DEV_ID_4F84 ) || \
+ ( d == DEV_ID_56AF ))
#define GFX_IS_DG2_G12_CONFIG(d) ( ( d == DEV_ID_4F85 ) || \
( d == DEV_ID_4F86 ) || \
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/inc/common/sku_wa.h new/gmmlib-intel-gmmlib-22.5.5/Source/inc/common/sku_wa.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/inc/common/sku_wa.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/inc/common/sku_wa.h 2024-11-29 11:17:25.000000000 +0100
@@ -194,7 +194,6 @@
typedef struct _WA_TABLE
{
// struct wa_3d
- unsigned int : 0;
WA_DECLARE(
WaAlignIndexBuffer,
@@ -203,7 +202,7 @@
WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)
// struct _wa_Gmm
- unsigned int : 0;
+ unsigned int Reserved0: 31; // Handle 4bytes alignment boundary to maintain ABI
WA_DECLARE(
WaValign2ForR8G8B8UINTFormat,
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/inc/umKmInc/UmKmDmaPerfTimer.h new/gmmlib-intel-gmmlib-22.5.5/Source/inc/umKmInc/UmKmDmaPerfTimer.h
--- old/gmmlib-intel-gmmlib-22.5.2/Source/inc/umKmInc/UmKmDmaPerfTimer.h 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/inc/umKmInc/UmKmDmaPerfTimer.h 2024-11-29 11:17:25.000000000 +0100
@@ -339,6 +339,48 @@
VPHAL_SR_SUBPIXEL_CONV_2X2,
VPHAL_SR_CONV_5X5_Y8,
+ //Media Copy
+ VPHAL_MCP_VEBOX_COPY,
+ VPHAL_MCP_RENDER_COPY,
+ VPHAL_MCP_BLT_COPY,
+
+ //OCL FC
+ VPHAL_OCL_FC_0LAYER,
+ VPHAL_OCL_FC_1LAYER,
+ VPHAL_OCL_FC_2LAYER,
+ VPHAL_OCL_FC_3LAYER,
+ VPHAL_OCL_FC_4LAYER,
+ VPHAL_OCL_FC_5LAYER,
+ VPHAL_OCL_FC_6LAYER,
+ VPHAL_OCL_FC_7LAYER,
+ VPHAL_OCL_FC_8LAYER,
+
+ //OCL FC w/ Primary Layer
+ VPHAL_OCL_FC_PRI_1LAYER,
+ VPHAL_OCL_FC_PRI_2LAYER,
+ VPHAL_OCL_FC_PRI_3LAYER,
+ VPHAL_OCL_FC_PRI_4LAYER,
+ VPHAL_OCL_FC_PRI_5LAYER,
+ VPHAL_OCL_FC_PRI_6LAYER,
+ VPHAL_OCL_FC_PRI_7LAYER,
+ VPHAL_OCL_FC_PRI_8LAYER,
+
+ //OCL FC w/ Rotation
+ VPHAL_OCL_FC_ROT_1LAYER,
+ VPHAL_OCL_FC_ROT_2LAYER,
+ VPHAL_OCL_FC_ROT_3LAYER,
+ VPHAL_OCL_FC_ROT_4LAYER,
+ VPHAL_OCL_FC_ROT_5LAYER,
+ VPHAL_OCL_FC_ROT_6LAYER,
+ VPHAL_OCL_FC_ROT_7LAYER,
+ VPHAL_OCL_FC_ROT_8LAYER,
+
+ //OCL FC FastExpress
+ VPHAL_OCL_FC_FP,
+ VPHAL_OCL_FC_FP_ROT,
+
+ //OCL 3DLut
+ VPHAL_OCL_3DLUT,
// ADD TAGS FOR NEW ADVPROC KRNS HERE
VPHAL_PERFTAG_MAX
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' '--exclude=.svnignore' old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CachePolicy/GmmXe2_LPGCachePolicy.cpp new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CachePolicy/GmmXe2_LPGCachePolicy.cpp
--- old/gmmlib-intel-gmmlib-22.5.2/Source/GmmLib/CachePolicy/GmmXe2_LPGCachePolicy.cpp 2024-09-06 11:51:19.000000000 +0200
+++ new/gmmlib-intel-gmmlib-22.5.5/Source/GmmLib/CachePolicy/GmmXe2_LPGCachePolicy.cpp 2024-11-29 11:17:25.000000000 +0100
@@ -43,7 +43,8 @@
// Define index of cache element
uint32_t Usage = 0;
- uint32_t ReservedPATIdx = 13; /* Rsvd PAT section 13-19 */
+ uint32_t ReservedPATIdx = 16; /* Rsvd PAT section 16-19 */
+ uint32_t ReservedPATIdxEnd = 20;
#if (_WIN32 && (_DEBUG || _RELEASE_INTERNAL))
void *pKmdGmmContext = NULL;
@@ -396,9 +397,6 @@
__GMM_ASSERT(false);
}
-#if (defined __linux__ || defined(WDDM_LINUX))
- IsCpuCacheable = false;
-#endif
// requested compressed and coherent
if (CompressionEnable && IsCpuCacheable)
{